Learn R Programming

seqgendiff (version 1.1.1)

seqgen_base: Simulate RNA-seq data from the (unrealistic) theoretical model.

Description

The main difference between seqgen_base and seqgen_diff is the output format.

Usage

seqgen_base(designmat, coefmat, dispvec)

Arguments

designmat

A numeric design matrix. The rows index the samples and the columns index the variables.

coefmat

A numeric matrix of coefficients. The rows index the genes and the columns index the variables.

dispvec

A vector of negative binomial dispersion parameters. Element i is the dispersion for gene i.

Value

A matrix of RNA-seq counts. The rows index the genes and the columns index the samples.

Details

You should be using thin_base instead of this. If you must simulate from the theoretical model, I would recommend trying out the powsimR package (https://github.com/bvieth/powsimR) from Vieth et al. (2017).

References

  • Vieth, Beate, Christoph Ziegenhain, Swati Parekh, Wolfgang Enard, and Ines Hellmann. "powsimR: power analysis for bulk and single cell RNA-seq experiments." Bioinformatics 33, no. 21 (2017): 3486-3488.