Learn R Programming

seqgendiff (version 1.1.1)

seqgen_diff: Theoretical sequence simulation for differential expression analysis.

Description

Generate a matrix of RNA-seq counts from a theoretical negative-binomial model.

Usage

seqgen_diff(designmat, coefmat, dispvec, design_sv = NULL,
  coef_sv = NULL)

Arguments

designmat

A numeric design matrix. The rows index the samples and the columns index the variables.

coefmat

A numeric matrix of coefficients. The rows index the genes and the columns index the variables.

dispvec

A vector of negative binomial dispersion parameters. Element i is the dispersion for gene i.

design_sv

A numeric design matrix for the surrogate variables. The rows index the samples and the columns index the surrogate variables.

coef_sv

A numeric matrix of coefficients for the surrogate variables. The rows index the genes and the columns index the variables.

Value

A list object with some or all of the following elements:

mat

A matrix of RNA-seq counts. The rows index the genes and the columns index the samples.

designmat

The user-provided designmat.

coefmat

The user-provided coefmat.

sv

The user-provided design_sv.

coef_sv

The user-provided coef_sv.

Details

You should be using thin_diff instead of this. If you must simulate from the theoretical model, I would recommend trying out the powsimR package (https://github.com/bvieth/powsimR) from Vieth et al. (2017).

References

  • Vieth, Beate, Christoph Ziegenhain, Swati Parekh, Wolfgang Enard, and Ines Hellmann. "powsimR: power analysis for bulk and single cell RNA-seq experiments." Bioinformatics 33, no. 21 (2017): 3486-3488.