The main difference between seqgen_base and seqgen_diff
is the output format.
seqgen_base(designmat, coefmat, dispvec)A numeric design matrix. The rows index the samples and the columns index the variables.
A numeric matrix of coefficients. The rows index the genes and the columns index the variables.
A vector of negative binomial dispersion parameters. Element i is the dispersion for gene i.
A matrix of RNA-seq counts. The rows index the genes and the columns index the samples.
You should be using thin_base instead of this. If you must
simulate from the theoretical model, I would recommend trying out
the powsimR package (https://github.com/bvieth/powsimR) from
Vieth et al. (2017).
Vieth, Beate, Christoph Ziegenhain, Swati Parekh, Wolfgang Enard, and Ines Hellmann. "powsimR: power analysis for bulk and single cell RNA-seq experiments." Bioinformatics 33, no. 21 (2017): 3486-3488.