Generate a matrix of RNA-seq counts from a theoretical negative-binomial model.
seqgen_diff(designmat, coefmat, dispvec, design_sv = NULL,
coef_sv = NULL)A numeric design matrix. The rows index the samples and the columns index the variables.
A numeric matrix of coefficients. The rows index the genes and the columns index the variables.
A vector of negative binomial dispersion parameters. Element i is the dispersion for gene i.
A numeric design matrix for the surrogate variables. The rows index the samples and the columns index the surrogate variables.
A numeric matrix of coefficients for the surrogate variables. The rows index the genes and the columns index the variables.
A list object with some or all of the following elements:
matA matrix of RNA-seq counts. The rows index the genes and the columns index the samples.
designmatThe user-provided designmat.
coefmatThe user-provided coefmat.
svThe user-provided design_sv.
coef_svThe user-provided coef_sv.
You should be using thin_diff instead of this. If you must
simulate from the theoretical model, I would recommend trying out
the powsimR package (https://github.com/bvieth/powsimR) from
Vieth et al. (2017).
Vieth, Beate, Christoph Ziegenhain, Swati Parekh, Wolfgang Enard, and Ines Hellmann. "powsimR: power analysis for bulk and single cell RNA-seq experiments." Bioinformatics 33, no. 21 (2017): 3486-3488.